@@ -23,23 +23,32 @@ class BaseConfig(ABC, BaseSettings):
     DB_PASS: str = "postgres"
     DB_HOST: str = "localhost"
     DB_PORT: int = 5432
-    SQLALCHEMY_TRACK_MODIFICATIONS = False
-    SECRET_KEY = "ADD_A_RANDOM_KEY_HERE"  # noqa: S105
-    ACCESS_TOKEN_EXPIRE_MINUTES = 1440
+    SQLALCHEMY_TRACK_MODIFICATIONS: bool = False
+    SECRET_KEY: str = "ADD_A_RANDOM_KEY_HERE"  # noqa: S105
+    ACCESS_TOKEN_EXPIRE_MINUTES: int = 1440
     USER_ACCESS_TOKEN: Optional[str]
-    AUTHER = "COOKIE"
-    MESSENGER = "GCP"
-    SCHEDULER = "RANDOM"
-    OBSERVER = "ELASTIC"
-    GOOGLE_APPLICATION_CREDENTIALS = "./keys.json"
-    GCP_PROJECT_ID = "YOUR_GCP_PROJECT_ID"
-    GCP_PUBSUB_TOPIC = "test-topic"
-    GCP_PUBSUB_SUB_ID = "test-sub"
-    CELERY_BROKER_URL = "redis://localhost:6379/0"
-    CELERY_RESULT_BACKEND = "redis://localhost:6379/0"
+    AUTHER: str = "COOKIE"
+    MESSENGER: str = "GCP"
+    SCHEDULER: str = "RANDOM"
+    OBSERVER: str = "ELASTIC"
+    GOOGLE_APPLICATION_CREDENTIALS: str = "./keys.json"
+    GCP_PROJECT_ID: str = "YOUR_GCP_PROJECT_ID"
+    GCP_PUBSUB_TOPIC: str = "test-topic"
+    GCP_PUBSUB_SUB_ID: str = "test-sub"
+    CELERY_BROKER_URL: str = "redis://localhost:6379/0"
+    CELERY_RESULT_BACKEND: str = "redis://localhost:6379/0"
 
     @abstractmethod
-    def get_sql_db_uri() -> str:
+    def get_config_name(self: "BaseConfig") -> str:
+        """Return Config name.
+
+        Returns:
+            str: Name of the config
+        """
+        pass
+
+    @abstractmethod
+    def get_sql_db_uri(self: "BaseConfig") -> str:
         """Get uri of the sql database.
 
         Returns:
@@ -51,3 +60,14 @@ class BaseConfig(ABC, BaseSettings):
         """Config for the BaseConfig class."""
 
         env_file = xdg_config_home() / ("orchestra") / ("conductor.env")
+
+
+class ConfigOfConfig(BaseSettings):
+    "Config for loading config"
+
+    BLACKCAP_CONFIG: str = "DEFAULT"
+
+    class Config:
+        """Config for ConfigofConfig class."""
+
+        env_file = xdg_config_home() / ("orchestra") / ("conductor.env")
